exceptiontools.ExtraPitchError
==============================

.. inheritance-diagram:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
